summaryrefslogtreecommitdiff
path: root/troveclient/compat
diff options
context:
space:
mode:
authorJenkins <jenkins@review.openstack.org>2013-12-12 18:29:46 +0000
committerGerrit Code Review <review@openstack.org>2013-12-12 18:29:46 +0000
commit30c174840b01babb74a6805ef9da85252ccc7b5a (patch)
tree92a99f85e71eb7080704106ac6706c0ea407c31b /troveclient/compat
parent176f4b6498291b802f6a73c3bc29bf42f0b9ff15 (diff)
parentc1e46dcd00d589464a97d14b3bfc8fcf87ace707 (diff)
downloadpython-troveclient-30c174840b01babb74a6805ef9da85252ccc7b5a.tar.gz
Merge "Fixed misspellings of common words"
Diffstat (limited to 'troveclient/compat')
-rw-r--r--troveclient/compat/base.py4
-rw-r--r--troveclient/compat/xml.py4
2 files changed, 4 insertions, 4 deletions
diff --git a/troveclient/compat/base.py b/troveclient/compat/base.py
index 7887522..915ec71 100644
--- a/troveclient/compat/base.py
+++ b/troveclient/compat/base.py
@@ -106,7 +106,7 @@ class Manager(utils.HookableMixin):
try:
os.makedirs(cache_dir, 0o755)
except OSError:
- # NOTE(kiall): This is typicaly either permission denied while
+ # NOTE(kiall): This is typically either permission denied while
# attempting to create the directory, or the directory
# already exists. Either way, don't fail.
pass
@@ -120,7 +120,7 @@ class Manager(utils.HookableMixin):
try:
setattr(self, cache_attr, open(path, mode))
except IOError:
- # NOTE(kiall): This is typicaly a permission denied while
+ # NOTE(kiall): This is typically a permission denied while
# attempting to write the cache file.
pass
diff --git a/troveclient/compat/xml.py b/troveclient/compat/xml.py
index 546d8fb..86c51fe 100644
--- a/troveclient/compat/xml.py
+++ b/troveclient/compat/xml.py
@@ -166,7 +166,7 @@ def element_to_dict(element):
def standardize_json_lists(json_dict):
"""
In XML, we might see something like {'instances':{'instances':[...]}},
- which we must change to just {'instances':[...]} to be compatable with
+ which we must change to just {'instances':[...]} to be compatible with
the true JSON format.
If any items are dictionaries with only one item which is a list,
@@ -253,7 +253,7 @@ def populate_element_from_dict(element, dict):
def modify_response_types(value, type_translator):
"""
This will convert some string in response dictionary to ints or bool
so that our respose is compatiable with code expecting JSON style responses
"""
if isinstance(value, str):
if value == 'True':
@@ -253,7 +253,7 @@ def populate_element_from_dict(element, dict):
"""
This will convert some string in response dictionary to ints or bool
- so that our respose is compatiable with code expecting JSON style responses
+ so that our respose is compatible with code expecting JSON style responses
"""
if isinstance(value, str):